/**
 * Created by JianJia.Zhou<jianjia.zhou> on 2022/5/26.
 */
export function copyText(text, tips) {
  uni.setClipboardData({
    data: text,
    success: function() {
      uni.hideLoading()
      uni.showToast({
        title: tips || '复制成功',
        icon: 'none'
      })
    }
  })
}

export function checkOS() {
  if (uni.getSystemInfoSync().platform === 'ios') {
    uni.showModal({
      title: '提示',
      content: '由于相关规范，iOS功能暂不可用',
      showCancel: false,
      success: function(res) {
        // res.confirm res.cancel
      }
    })
    return false
  }
  return true
}

// 节流
export function throttle(fn, wait = 200) {
	let last, timer, now;
	return function() {
		now = Date.now();
		if (last && now - last < wait) {
			clearTimeout(timer);
			timer = setTimeout(function() {
				last = now;
				fn.call(this, ...arguments);
			}, wait);
		} else {
			last = now;
			fn.call(this, ...arguments);
		}
	};
}
// 防抖
export function debounce(fn, wait = 200) {
	let timer;
	return function() {
		let context = this;
		let args = arguments;
		if (timer) clearTimeout(timer);
		timer = setTimeout(() => {
			fn.apply(context, args);
		}, wait)
	}
}

const shareMessage = user => {
  // #ifdef  MP-KUAISHOU
  const title ="四海剧场"
    // #endif
    // #ifdef  MP-TOUTIAO | MP-WEIXIN
  const title ="张四爷剧场"
  // #endif
  console.log('-->data', user)
  return {
    path: `/pages/index/index?user_id=${user.id}`,
    title: title,
    desc: title
    // imageUrl: ''
  }
}

export default {
  copyText,
  checkOS,
  throttle,
  debounce,
  shareMessage
}
